@@ -19,7 +19,6 @@
 package opennlp.tools.parser;
 
 import java.util.Collection;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
@@ -106,8 +105,7 @@ public abstract class AbstractContextGenerator {
         Collection<Parse> nextPunct = children[ci].getNextPunctuationSet();
         if (includePunctuation && nextPunct != null) {
           //TODO: make sure multiple punctuation comes out the same
-          for (Iterator<Parse> pit = nextPunct.iterator(); pit.hasNext();) {
-            Parse punct = pit.next();
+          for (Parse punct : nextPunct) {
             production.append(punct.getType()).append(",");
           }
         }
@@ -118,9 +116,8 @@ public abstract class AbstractContextGenerator {
 
   protected void cons2(List<String> features, Cons c0, Cons c1, Collection<Parse> punct1s, boolean bigram) {
     if (punct1s != null) {
-      for (Iterator<Parse> pi = punct1s.iterator();pi.hasNext();) {
-        Parse p = pi.next();
-        String punctbo = punctbo(p,c1.index <= 0 ? c1.index - 1 : c1.index);
+      for (Parse p : punct1s) {
+        String punctbo = punctbo(p, c1.index <= 0 ? c1.index - 1 : c1.index);
 
         //punctbo(1);
         features.add(punctbo);
@@ -137,8 +134,8 @@ public abstract class AbstractContextGenerator {
 
         //cons(0)punctbo(1)cons(1)
         if (bigram) features.add(c0.cons + "," + punctbo + "," + c1.cons);
-        if (c1.unigram)  features.add(c0.consbo + "," + punctbo + "," + c1.cons);
-        if (c0.unigram)  features.add(c0.cons + "," + punctbo + "," + c1.consbo);
+        if (c1.unigram) features.add(c0.consbo + "," + punctbo + "," + c1.cons);
+        if (c0.unigram) features.add(c0.cons + "," + punctbo + "," + c1.consbo);
         features.add(c0.consbo + "," + punctbo + "," + c1.consbo);
       }
     }
@@ -170,10 +167,9 @@ public abstract class AbstractContextGenerator {
     //  features.add("stage=cons(0),cons(1),cons(2)");
     if (punct1s != null) {
       if (c0.index == -2) {
-        for (Iterator<Parse> pi = punct1s.iterator(); pi.hasNext();) {
-          Parse p = pi.next();
+        for (Parse p : punct1s) {
           // String punct = punct(p,c1.index);
-          String punctbo = punctbo(p,c1.index <= 0 ? c1.index - 1 : c1.index);
+          String punctbo = punctbo(p, c1.index <= 0 ? c1.index - 1 : c1.index);
           //punct(-2)
           //TODO consider changing
           //features.add(punct);
@@ -185,8 +181,7 @@ public abstract class AbstractContextGenerator {
     }
     if (punct2s != null) {
       if (c2.index == 2) {
-        for (Iterator<Parse> pi = punct2s.iterator(); pi.hasNext();) {
-          Parse p = pi.next();
+        for (Parse p : punct2s) {
           // String punct = punct(p,c2.index);
           String punctbo = punctbo(p, c2.index);
           //punct(2)
@@ -199,33 +194,33 @@ public abstract class AbstractContextGenerator {
       }
       if (punct1s != null) {
         //cons(0),punctbo(1),cons(1),punctbo(2),cons(2)
-        for (Iterator<Parse> pi2 = punct2s.iterator(); pi2.hasNext();) {
-          String punctbo2 = punctbo(pi2.next(),c2.index <= 0 ? c2.index - 1 : c2.index);
-          for (Iterator<Parse> pi1 = punct1s.iterator(); pi1.hasNext();) {
-            String punctbo1 = punctbo(pi1.next(),c1.index <= 0 ? c1.index - 1 : c1.index);
+        for (Parse punct2 : punct2s) {
+          String punctbo2 = punctbo(punct2, c2.index <= 0 ? c2.index - 1 : c2.index);
+          for (Parse punct1 : punct1s) {
+            String punctbo1 = punctbo(punct1, c1.index <= 0 ? c1.index - 1 : c1.index);
             if (trigram)
               features.add(c0.cons + "," + punctbo1 + "," + c1.cons + "," + punctbo2 + "," + c2.cons);
 
             if (bigram2)
-              features.add(c0.consbo + "," + punctbo1 + "," + c1.cons   + "," + punctbo2 + "," + c2.cons);
+              features.add(c0.consbo + "," + punctbo1 + "," + c1.cons + "," + punctbo2 + "," + c2.cons);
             if (c0.unigram && c2.unigram)
               features.add(c0.cons + "," + punctbo1 + "," + c1.consbo + "," + punctbo2 + "," + c2.cons);
             if (bigram1)
-              features.add(c0.cons + "," + punctbo1 + "," + c1.cons + "," + punctbo2 + ","  + c2.consbo);
+              features.add(c0.cons + "," + punctbo1 + "," + c1.cons + "," + punctbo2 + "," + c2.consbo);
 
             if (c2.unigram)
               features.add(c0.consbo + "," + punctbo1 + "," + c1.consbo + "," + punctbo2 + "," + c2.cons);
             if (c1.unigram)
-              features.add(c0.consbo + "," + punctbo1 + "," + c1.cons   + "," + punctbo2 + "," + c2.consbo);
+              features.add(c0.consbo + "," + punctbo1 + "," + c1.cons + "," + punctbo2 + "," + c2.consbo);
             if (c0.unigram)
-              features.add(c0.cons   + "," + punctbo1 + "," + c1.consbo + "," + punctbo2 + "," + c2.consbo);
+              features.add(c0.cons + "," + punctbo1 + "," + c1.consbo + "," + punctbo2 + "," + c2.consbo);
 
             features.add(c0.consbo + "," + punctbo1 + "," + c1.consbo + "," + punctbo2 + "," + c2.consbo);
 
             if (zeroBackOff) {
-              if (bigram1) features.add(c0.cons   + "," + punctbo1 + "," + c1.cons   + "," + punctbo2);
-              if (c1.unigram)  features.add(c0.consbo + "," + punctbo1 + "," + c1.cons   + "," + punctbo2);
-              if (c0.unigram)  features.add(c0.cons   + "," + punctbo1 + "," + c1.consbo + "," + punctbo2);
+              if (bigram1) features.add(c0.cons + "," + punctbo1 + "," + c1.cons + "," + punctbo2);
+              if (c1.unigram) features.add(c0.consbo + "," + punctbo1 + "," + c1.cons + "," + punctbo2);
+              if (c0.unigram) features.add(c0.cons + "," + punctbo1 + "," + c1.consbo + "," + punctbo2);
               features.add(c0.consbo + "," + punctbo1 + "," + c1.consbo + "," + punctbo2);
             }
           }
@@ -233,26 +228,26 @@ public abstract class AbstractContextGenerator {
       }
       else { //punct1s == null
         //cons(0),cons(1),punctbo(2),cons(2)
-        for (Iterator<Parse> pi2 = punct2s.iterator(); pi2.hasNext();) {
-          String punctbo2 = punctbo(pi2.next(),c2.index <= 0 ? c2.index - 1 : c2.index);
-          if (trigram) features.add(c0.cons   + "," + c1.cons   + "," + punctbo2 + "," + c2.cons);
+        for (Parse punct2 : punct2s) {
+          String punctbo2 = punctbo(punct2, c2.index <= 0 ? c2.index - 1 : c2.index);
+          if (trigram) features.add(c0.cons + "," + c1.cons + "," + punctbo2 + "," + c2.cons);
 
           if (bigram2)
-            features.add(c0.consbo + "," + c1.cons   + ","  + punctbo2 + "," + c2.cons);
+            features.add(c0.consbo + "," + c1.cons + "," + punctbo2 + "," + c2.cons);
           if (c0.unigram && c2.unigram)
-            features.add(c0.cons    + "," + c1.consbo + "," + punctbo2 + "," + c2.cons);
-          if (bigram1) features.add(c0.cons + "," + c1.cons   + "," +  punctbo2 + "," + c2.consbo);
+            features.add(c0.cons + "," + c1.consbo + "," + punctbo2 + "," + c2.cons);
+          if (bigram1) features.add(c0.cons + "," + c1.cons + "," + punctbo2 + "," + c2.consbo);
 
           if (c2.unigram) features.add(c0.consbo + "," + c1.consbo + "," + punctbo2 + "," + c2.cons);
-          if (c1.unigram) features.add(c0.consbo + "," + c1.cons   + "," + punctbo2 + "," + c2.consbo);
-          if (c0.unigram) features.add(c0.cons   + "," + c1.consbo + "," + punctbo2 + "," + c2.consbo);
+          if (c1.unigram) features.add(c0.consbo + "," + c1.cons + "," + punctbo2 + "," + c2.consbo);
+          if (c0.unigram) features.add(c0.cons + "," + c1.consbo + "," + punctbo2 + "," + c2.consbo);
 
           features.add(c0.consbo + "," + c1.consbo + "," + punctbo2 + "," + c2.consbo);
 
           if (zeroBackOff) {
-            if (bigram1) features.add(c0.cons   + "," + c1.cons   + "," + punctbo2);
-            if (c1.unigram)  features.add(c0.consbo + "," + c1.cons   + "," + punctbo2);
-            if (c0.unigram)  features.add(c0.cons   + "," + c1.consbo + "," + punctbo2);
+            if (bigram1) features.add(c0.cons + "," + c1.cons + "," + punctbo2);
+            if (c1.unigram) features.add(c0.consbo + "," + c1.cons + "," + punctbo2);
+            if (c0.unigram) features.add(c0.cons + "," + c1.consbo + "," + punctbo2);
             features.add(c0.consbo + "," + c1.consbo + "," + punctbo2);
           }
         }
@@ -261,8 +256,8 @@ public abstract class AbstractContextGenerator {
     else {
       if (punct1s != null) {
         //cons(0),punctbo(1),cons(1),cons(2)
-        for (Iterator<Parse> pi1 = punct1s.iterator(); pi1.hasNext();) {
-          String punctbo1 = punctbo(pi1.next(), c1.index <= 0 ? c1.index - 1 : c1.index);
+        for (Parse punct1 : punct1s) {
+          String punctbo1 = punctbo(punct1, c1.index <= 0 ? c1.index - 1 : c1.index);
           if (trigram)
             features.add(c0.cons + "," + punctbo1 + "," + c1.cons + "," + c2.cons);
 
@@ -271,16 +266,16 @@ public abstract class AbstractContextGenerator {
           if (c0.unigram && c2.unigram)
             features.add(c0.cons + "," + punctbo1 + "," + c1.consbo + "," + c2.cons);
           if (bigram1)
-            features.add(c0.cons + "," + punctbo1   + "," + c1.cons + "," + c2.consbo);
+            features.add(c0.cons + "," + punctbo1 + "," + c1.cons + "," + c2.consbo);
 
           if (c2.unigram)
             features.add(c0.consbo + "," + punctbo1 + "," + c1.consbo + "," + c2.cons);
           if (c1.unigram)
-            features.add(c0.consbo + "," + punctbo1 + "," + c1.cons   + "," + c2.consbo);
+            features.add(c0.consbo + "," + punctbo1 + "," + c1.cons + "," + c2.consbo);
           if (c0.unigram)
             features.add(c0.cons + "," + punctbo1 + "," + c1.consbo + "," + c2.consbo);
 
-          features.add(c0.consbo + "," + punctbo1   + "," + c1.consbo + "," + c2.consbo);
+          features.add(c0.consbo + "," + punctbo1 + "," + c1.consbo + "," + c2.consbo);
 
           //zero backoff case covered by cons(0)cons(1)
         }
@@ -315,13 +310,11 @@ public abstract class AbstractContextGenerator {
     StringBuilder feat = new StringBuilder(20);
     feat.append("s").append(i).append("=");
     if (punctuation != null) {
-      for (Iterator<Parse> pi = punctuation.iterator(); pi.hasNext();) {
-        Parse punct = pi.next();
+      for (Parse punct : punctuation) {
         if (node != null) {
           feat.append(node.getHead().getCoveredText()).append("|").append(type)
-              .append("|").append(node.getType()).append("|").append(punct.getType());
-        }
-        else {
+                  .append("|").append(node.getType()).append("|").append(punct.getType());
+        } else {
           feat.append(type).append("|").append(EOS).append("|").append(punct.getType());
         }
         features.add(feat.toString());
@@ -330,8 +323,7 @@ public abstract class AbstractContextGenerator {
         feat.append("s").append(i).append("*=");
         if (node != null) {
           feat.append(type).append("|").append(node.getType()).append("|").append(punct.getType());
-        }
-        else {
+        } else {
           feat.append(type).append("|").append(EOS).append("|").append(punct.getType());
         }
         features.add(feat.toString());
@@ -413,8 +405,7 @@ public abstract class AbstractContextGenerator {
     int leftIndex = 0;
     int prevHeadIndex = -1;
 
-    for (int fi = 0; fi < rf.size(); fi++) {
-      Parse fn = rf.get(fi);
+    for (Parse fn : rf) {
       int headIndex = fn.getHeadIndex();
       if (headIndex != prevHeadIndex) {
         nodes[leftIndex] = fn;
