@@ -22,12 +22,12 @@ import java.io.InputStreamReader;
 import java.io.Reader;
 import java.nio.charset.StandardCharsets;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class SgmlParserTest {
 
   @Test
-  public void testParse1() throws IOException {
+  void testParse1() throws IOException {
 
     try (Reader in = new InputStreamReader(
         SgmlParserTest.class.getResourceAsStream("parsertest1.sgml"), StandardCharsets.UTF_8)) {
