@@ -20,8 +20,8 @@ package opennlp.tools.namefind;
 import java.io.ByteArrayOutputStream;
 import java.io.OutputStream;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 import opennlp.tools.cmdline.namefind.NameEvaluationErrorListener;
 import opennlp.tools.util.Span;
@@ -36,7 +36,9 @@ import static org.mockito.Mockito.when;
 public class TokenNameFinderEvaluatorTest {
 
 
-  /** Return a dummy name finder that always return something expected */
+  /**
+   * Return a dummy name finder that always return something expected
+   */
   public TokenNameFinder mockTokenNameFinder(Span[] ret) {
     TokenNameFinder mockInstance = mock(TokenNameFinder.class);
     when(mockInstance.find(any(String[].class))).thenReturn(ret);
@@ -44,7 +46,7 @@ public class TokenNameFinderEvaluatorTest {
   }
 
   @Test
-  public void testPositive() {
+  void testPositive() {
     OutputStream stream = new ByteArrayOutputStream();
     TokenNameFinderEvaluationMonitor listener = new NameEvaluationErrorListener(stream);
 
@@ -54,13 +56,13 @@ public class TokenNameFinderEvaluatorTest {
 
     eval.evaluateSample(createSimpleNameSampleA());
 
-    Assert.assertEquals(1.0, eval.getFMeasure().getFMeasure(), 0.0);
+    Assertions.assertEquals(1.0, eval.getFMeasure().getFMeasure());
 
-    Assert.assertEquals(0, stream.toString().length());
+    Assertions.assertEquals(0, stream.toString().length());
   }
 
   @Test
-  public void testNegative() {
+  void testNegative() {
     OutputStream stream = new ByteArrayOutputStream();
     TokenNameFinderEvaluationMonitor listener = new NameEvaluationErrorListener(stream);
 
@@ -70,21 +72,20 @@ public class TokenNameFinderEvaluatorTest {
 
     eval.evaluateSample(createSimpleNameSampleA());
 
-    Assert.assertEquals(0.8, eval.getFMeasure().getFMeasure(), 0.0);
+    Assertions.assertEquals(0.8, eval.getFMeasure().getFMeasure());
 
-    Assert.assertNotSame(0, stream.toString().length());
+    Assertions.assertNotSame(0, stream.toString().length());
   }
 
 
-
   private static String[] sentence = {"U", ".", "S", ".", "President", "Barack", "Obama", "is",
       "considering", "sending", "additional", "American", "forces",
       "to", "Afghanistan", "."};
 
   private static NameSample createSimpleNameSampleA() {
 
-    Span[] names = { new Span(0, 4, "Location"), new Span(5, 7, "Person"),
-        new Span(14, 15, "Location") };
+    Span[] names = {new Span(0, 4, "Location"), new Span(5, 7, "Person"),
+        new Span(14, 15, "Location")};
 
     NameSample nameSample;
     nameSample = new NameSample(sentence, names, false);
@@ -94,7 +95,7 @@ public class TokenNameFinderEvaluatorTest {
 
   private static NameSample createSimpleNameSampleB() {
 
-    Span[] names = { new Span(0, 4, "Location"), new Span(14, 15, "Location") };
+    Span[] names = {new Span(0, 4, "Location"), new Span(14, 15, "Location")};
 
     NameSample nameSample;
     nameSample = new NameSample(sentence, names, false);
